@@ -68,6 +68,8 @@ class Consumer:
         except Exception as e:
             logging.error(f"[Consumer] Failed decode message to JSON {str(e)}")
             raise e
+        if 'message_type' not in msg:
+            raise Exception("message_type not in msg from RBMQ")
         logging.debug(f"[Consumer] Message type ready {type(msg['message_type'])}")
         if msg['message_type'] == RBMQ_aggregation_status:
             logging.debug("[Consumer] Putting agg_id to Queue: " + str(msg['body']['aggregation_id']))
@@ -85,9 +87,9 @@ class Consumer:
         try:
             logging.info("[Consumer] Starting rabbitmq consumer")
             self.channel.start_consuming()
-
         except Exception as e:
-            self.stop()
+            logging.error(f"[Consumer] Error starting rabbitmq consumer: {e}")
+            self.stop(e)
 
     def stop(self, err=None):
         logging.info("[Consumer] Stopping rabbitmq consumer: " + str(err))
