@@ -1,4 +1,5 @@
 import json
+import logging
 import os
 import warnings
 from http import HTTPStatus
@@ -97,7 +98,7 @@ class Client:
                                 auth=(self.__leaf_name, self.__leaf_password), verify=self.__verify)
 
             if resp.status_code != HTTPStatus.CREATED:
-                raise Exception(resp.json()["message"])
+                raise Exception(resp.json())
 
             login_data = resp.json()["data"]
             try:
@@ -110,12 +111,12 @@ class Client:
                 self.consumer = consumer.spawn_consumer_thread()
                 return self.__status == "logged_in"
             except Exception as e:
-                msg = "Failed to parse response from login"
-                raise Exception(msg)
+                raise Exception(f"Failed to parse response from login: {e}")
 
         except Exception as e:
             msg = "Login failed for {}: {}".format(self.__leaf_name, e)
-            raise Exception(msg)
+            logging.error(msg)
+            return False
 
     def logout(self):
         if not self.__status == "logged_in" or not self.__access_token:
